@@ -112,6 +112,7 @@ get_static_caps (SwService *service)
     HAS_PHOTO_UPLOAD_IFACE,
     HAS_VIDEO_UPLOAD_IFACE,
     HAS_BANISHABLE_IFACE,
+    HAS_COLLECTIONS_IFACE,
 
     NULL
   };
@@ -341,7 +342,7 @@ _upload_file (SwServicePhotobucket *self,
               MediaType upload_type,
               const gchar *filename,
               GHashTable *extra_fields,
-              RestProxyCallAsyncCallback upload_cb,
+              RestProxyCallUploadCallback upload_cb,
               GError **error)
 {
   SwServicePhotobucketPrivate *priv = self->priv;
@@ -411,11 +412,11 @@ _upload_file (SwServicePhotobucket *self,
 
   SW_DEBUG (PHOTOBUCKET, "Uploading %s", basename);
 
-  rest_proxy_call_async (call,
-                         upload_cb,
-                         G_OBJECT (self),
-                         GINT_TO_POINTER (opid),
-                         NULL);
+  rest_proxy_call_upload (call,
+                          upload_cb,
+                          G_OBJECT (self),
+                          GINT_TO_POINTER (opid),
+                          NULL);
 
 OUT:
   g_free (basename);
@@ -795,6 +796,8 @@ collections_iface_init (gpointer g_iface,
 
 static void
 _upload_photo_cb (RestProxyCall *call,
+                  gsize          total,
+                  gsize          uploaded,
                   const GError  *error,
                   GObject       *weak_object,
                   gpointer       user_data)
@@ -806,7 +809,8 @@ _upload_photo_cb (RestProxyCall *call,
     sw_photo_upload_iface_emit_photo_upload_progress (self, opid, -1,
         error->message);
   } else {
-    sw_photo_upload_iface_emit_photo_upload_progress (self, opid, 100, "");
+    gint percent = (gdouble) uploaded / (gdouble) total * 100;
+    sw_photo_upload_iface_emit_photo_upload_progress (self, opid, percent, "");
   }
 }
 
@@ -820,7 +824,7 @@ _photobucket_upload_photo (SwPhotoUploadIface    *self,
   gint opid;
 
   opid = _upload_file (SW_SERVICE_PHOTOBUCKET (self), PHOTO, filename,
-                       fields, (RestProxyCallAsyncCallback) _upload_photo_cb,
+                       fields, (RestProxyCallUploadCallback) _upload_photo_cb,
                        &error);
 
   if (error) {
@@ -847,6 +851,8 @@ photo_upload_iface_init (gpointer g_iface,
 
 static void
 _upload_video_cb (RestProxyCall *call,
+                  gsize          total,
+                  gsize          uploaded,
                   const GError  *error,
                   GObject       *weak_object,
                   gpointer       user_data)
@@ -858,7 +864,8 @@ _upload_video_cb (RestProxyCall *call,
     sw_video_upload_iface_emit_video_upload_progress (self, opid, -1,
         error->message);
   } else {
-    sw_video_upload_iface_emit_video_upload_progress (self, opid, 100, "");
+    gint percent = (gdouble) uploaded / (gdouble) total * 100;
+    sw_video_upload_iface_emit_video_upload_progress (self, opid, percent, "");
   }
 }
 
@@ -872,7 +879,7 @@ _photobucket_upload_video (SwVideoUploadIface    *self,
   gint opid;
 
   opid = _upload_file (SW_SERVICE_PHOTOBUCKET (self), VIDEO, filename, fields,
-                       (RestProxyCallAsyncCallback) _upload_video_cb, &error);
+                       (RestProxyCallUploadCallback) _upload_video_cb, &error);
 
   if (error) {
     dbus_g_method_return_error (context, error);
